/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

// Qt includes
#include <QMainWindow>

// Qt classes
class QTabWidget;
class QLabel;
class QAction;

// Local classes
class Database;
class SettingsPage;
class PlayersPage;
class ScorePage;
class RankingPage;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow();
    void loadTournament(QString dbToOpen = QString());
    QString absolutePath(QString fileName);
    void resizeEvent(QResizeEvent *event);

public slots:
    void updateStatus(QString message);
    void settingsSaved();
    void dbReset();
    void setScoreTabEnabled(bool state);
    void tournamentStarted();

private: // Functions
    void databaseChanged(QString dbFileName);
    void setPlayersTabName();
    void checkEnableRankingPage();

private slots:
    void tabChanged(int tab);
    void startNewTournament();
    void triggerLoadTournament();
    void quit();
    void showHandbook();
    void showAboutWindow();
    void showExportDialog();

private: // Variables
    QString m_iconPath;
    QLabel *m_headerLabel;
    QTabWidget *m_tabWidget;
    Database *m_db;
    SettingsPage *m_settingsPage;
    PlayersPage *m_playersPage;
    ScorePage *m_scorePage;
    RankingPage *m_rankingPage;
    QAction *m_exportAction;

};

#endif // MAINWINDOW_H
