/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SETTINGSPAGE_H
#define SETTINGSPAGE_H

// Qt includes
#include <QWidget>

// Qt classes
class QGroupBox;
class QRadioButton;
class QLabel;
class QSpinBox;
class QPushButton;

// Local Classes
class Database;

class SettingsPage : public QWidget
{
    Q_OBJECT

public:
    explicit SettingsPage(QWidget *parent, Database *db);
    void resetGui();
    void reload();
    void setToSaved();

signals:
    void statusUpdate(QString message);
    void settingsSaved();
    void dbReset();

private slots:
    void updateTournamentModeDescription();
    void resetDatabase();
    void saveSettings();

private: // Variables
    Database *m_db;
    QString m_fixedPairsDescription;
    QString m_singlePlayersDescription;
    QGroupBox *m_databaseBox;
    QRadioButton *m_pairs;
    QRadioButton *m_singlePlayers;
    QLabel *m_tournamentModeHeaderLabel;
    QLabel *m_tournamentModeLabel;
    QSpinBox *m_boogerScore;
    QLabel *m_boogerScoreLabel;
    QSpinBox *m_gamesPerRound;
    QLabel *m_gamesPerRoundLabel;
    QPushButton *m_resetDatabase;
    QPushButton *m_saveSettings;
    QLabel *m_dbFileLabel;
    QLabel *m_mtVersionHeaderLabel;
    QLabel *m_mtVersionLabel;

};

#endif // SETTINGSPAGE_H
